@@ -31,11 +31,12 @@
 
 #include <Lum/OS/Main.h>
 
+#include <Lum/OS/Manager/Repository.h>
+
 #include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 
 #include "Configuration.h"
 #include "Selector.h"
@@ -163,6 +164,15 @@ public:
     }
   }
 
+  void AllowScreenBlanking(bool allow)
+  {
+    Lum::OS::Manager::DisplayManager *displayManager=Lum::OS::Manager::repository->GetDisplayManager();
+
+    if (displayManager!=NULL) {
+      displayManager->AllowScreenBlanking(allow);
+    }
+  }
+
   void SetState(State state)
   {
     if (this->state==state) {
@@ -178,12 +188,15 @@ public:
     case stateStoped:
       startAction->Enable();
       stopAction->Disable();
+      AllowScreenBlanking(true);
       break;
     case stateRunning:
       restartAction->Enable();
+      AllowScreenBlanking(false);
     case stateAlerting:
       startAction->Disable();
       stopAction->Enable();
+      AllowScreenBlanking(false);
       break;
     }
 
@@ -218,40 +231,16 @@ public:
 
   virtual void PreInit()
   {
-    Lum::Button      *button;
-    Lum::ButtonRow   *buttonRow;
-    Lum::Panel       *panel;
-
-    panel=new Lum::VPanel();
-    panel->SetFlex(true,true);
-
     value->SetText(L"4:00");
     value->SetFlex(true,true);
-    panel->Add(value);
 
-    panel->Add(new Lum::VSpace());
-
-    buttonRow=new Lum::ButtonRow();
-    buttonRow->SetFlex(true,false);
-
-    button=new Lum::Button(_(L"BUTTON_START",L"_Start"));
-    button->SetFlex(true,true);
-    button->SetModel(startAction);
-    buttonRow->Add(button);
-
-    button=new Lum::Button(_(L"BUTTON_RESTART",L"_Restart"));
-    button->SetFlex(true,true);
-    button->SetModel(restartAction);
-    buttonRow->Add(button);
-
-    button=new Lum::Button(_(L"BUTTON_STOP",L"Sto_p"));
-    button->SetFlex(true,true);
-    button->SetModel(stopAction);
-    buttonRow->Add(button);
-
-    panel->Add(buttonRow);
-
-    SetMain(panel);
+    SetMain(Lum::VPanel::Create(true,true)
+            ->Add(value)
+            ->AddSpace()
+            ->Add(Lum::ButtonRow::Create(true,false)
+                  ->Add(Lum::Button::Create(_(L"BUTTON_START",L"_Start"),startAction,true,true))
+                  ->Add(Lum::Button::Create(_(L"BUTTON_RESTART",L"_Restart"),restartAction,true,true))
+                  ->Add(Lum::Button::Create(_(L"BUTTON_STOP",L"Sto_p"),stopAction,true,true))));
 
     Lum::MenuDesc *menu=new Lum::MenuDesc();
 
