@@ -29,34 +29,20 @@
 #include <Lum/Label.h>
 #include <Lum/Panel.h>
 #include <Lum/Slider.h>
-#include <Lum/Space.h>
 #include <Lum/Table.h>
 #include <Lum/TextValue.h>
 
-#include "Configuration.h"
-
 Selector::Selector(Lum::Model::Int* minutes, Lum::Model::Int *seconds)
  : value(new Lum::Model::String()),
    minutes(minutes),
    seconds(seconds),
-   list(new Lum::Model::ListTable(2)),
+   list(new TeasModel(teas,new TeasDataProvider())),
    selection(new Lum::Model::SingleLineSelection()),
    addAction(new Lum::Model::Action()),
    updateAction(new Lum::Model::Action()),
    removeAction(new Lum::Model::Action()),
    okAction(new Lum::Model::Action())
 {
-  for (size_t i=0; i<teas.size(); i++) {
-    Lum::Model::ListTable::StdEntry *entry;
-
-    entry=new Lum::Model::ListTable::StdEntry(list);
-
-    entry->SetString(1,teas[i].name);
-    entry->SetString(2,GetTimeString(teas[i].minutes,teas[i].seconds));
-
-    list->Append(entry);
-  }
-
   updateAction->Disable();
   removeAction->Disable();
 
@@ -73,46 +59,25 @@ Selector::Selector(Lum::Model::Int* minutes, Lum::Model::Int *seconds)
   Observe(GetClosedAction());
 }
 
-std::wstring Selector::GetTimeString(size_t minutes, size_t seconds) const
-{
-  std::wstring tmp;
-
-  tmp=Lum::Base::NumberToWString(minutes);
-  tmp.append(L":");
-  if (seconds<10) {
-    tmp.append(L"0");
-  }
-  tmp.append(Lum::Base::NumberToWString(seconds));
-
-  return tmp;
-}
-
 void Selector::PreInit()
 {
-  Lum::Button           *button;
-  Lum::ButtonRow        *buttonRow;
   Lum::Label            *label;
-  Lum::Panel            *panel,*horiz,*vert;
+  Lum::Panel            *panel,*horiz;
   Lum::Slider           *slider;
   Lum::Table            *table;
   Lum::TextValue        *value;
   Lum::Model::HeaderRef headerModel;
 
-  panel=new Lum::VPanel();
+  panel=Lum::VPanel::Create();
 
-  label=new Lum::Label();
-  label->SetFlex(true,true);
+  label=Lum::Label::Create(true,true);
 
-  value=new Lum::TextValue();
-  value->SetFlex(true,false);
-  value->SetModel(this->value);
-  value->SetFont(Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                           Lum::OS::Display::fontScaleCaption2));
+  value=Lum::TextValue::Create(this->value,Lum::TextValue::centered,true,false);
+  value->SetFont(Lum::OS::display->GetFont(Lum::OS::Display::fontScaleCaption2));
   value->SetStyle(Lum::OS::Font::bold);
-  value->SetAlignment(Lum::TextValue::centered);
   panel->Add(value);
 
-  panel->Add(new Lum::VSpace());
+  panel->AddSpace();
 
   slider=new Lum::HSlider();
   slider->SetWidth(Lum::Base::Size::stdCharWidth,30);
@@ -130,32 +95,15 @@ void Selector::PreInit()
   label->AddLabel(_(L"LBL_SECONDS",L"Seconds"),slider);
   panel->Add(label);
 
-  panel->Add(new Lum::VSpace());
+  panel->AddSpace();
 
-  horiz=new Lum::HPanel();
-  horiz->SetFlex(true,true);
+  horiz=Lum::HPanel::Create(true,true);
+  horiz->Add(Lum::VPanel::Create(false,true)
+             ->Add(Lum::Button::Create(_(L"BTN_ADD",L"_Add"),addAction,true,false))
+             ->Add(Lum::Button::Create(_(L"BTN_UPDATE",L"_Update"),updateAction,true,false))
+             ->Add(Lum::Button::Create(_(L"BTN_REMOVE",L"_Remove"),removeAction,true,false)));
 
-  vert=new Lum::VPanel();
-  vert->SetFlex(false,true);
-
-  button=new Lum::Button(_(L"BTN_ADD",L"_Add"));
-  button->SetFlex(true,false);
-  button->SetModel(addAction);
-  vert->Add(button);
-
-  button=new Lum::Button(_(L"BTN_UPDATE",L"_Update"));
-  button->SetFlex(true,false);
-  button->SetModel(updateAction);
-  vert->Add(button);
-
-  button=new Lum::Button(_(L"BTN_REMOVE",L"_Remove"));
-  button->SetFlex(true,false);
-  button->SetModel(removeAction);
-  vert->Add(button);
-
-  horiz->Add(vert);
-
-  horiz->Add(new Lum::HSpace());
+  horiz->AddSpace();
 
   headerModel=new Lum::Model::HeaderImpl();
   headerModel->AddColumn(_(L"TBL_HEADER_TEA",L"Tea"),Lum::Base::Size::stdCharWidth,20,true);
@@ -172,12 +120,8 @@ void Selector::PreInit()
   horiz->Add(table);
 
   panel->Add(horiz);
-
-  panel->Add(new Lum::VSpace());
-
-  buttonRow=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
-  buttonRow->SetFlex(true,false);
-  panel->Add(buttonRow);
+  panel->AddSpace();
+  panel->Add(Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction(),true,false));
 
   SetMain(panel);
 
@@ -227,47 +171,32 @@ void Selector::Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg)
                                      _(L"DLG_TEA_NAME_TEXT",
                                        L"Please enter the name of the tea:"),
                                        name)) {
-      Lum::Model::ListTable::StdEntry *entry;
-      Tea                             tea;
+      Tea tea;
 
       // The tea list
       tea.name=name->Get();
       tea.minutes=minutes->Get();
       tea.seconds=seconds->Get();
 
-      teas.push_back(tea);
-
       // The selection list
-      entry=new Lum::Model::ListTable::StdEntry(list);
-
-      entry->SetString(1,name->Get());
-      entry->SetString(2,GetTimeString(minutes->Get(),seconds->Get()));
-
-      list->Append(entry);
+      list->Append(tea);
 
       configurationChanged=true;
     }
   }
   else if (model==updateAction && updateAction->IsFinished()) {
-    Lum::Model::ListTable::StdEntry *entry;
-
     assert(selection->HasSelection());
 
-    entry=dynamic_cast<Lum::Model::ListTable::StdEntry*>(list->GetEntry(selection->GetLine()));
-
-    assert(entry!=NULL);
-
     teas[selection->GetLine()-1].minutes=minutes->Get();
     teas[selection->GetLine()-1].seconds=seconds->Get();
 
-    entry->SetString(2,GetTimeString(minutes->Get(),seconds->Get()));
+    list->RedrawRow(selection->GetLine());
 
     configurationChanged=true;
   }
   else if (model==removeAction && removeAction->IsFinished()) {
     assert(selection->HasSelection());
 
-    teas.erase(teas.begin()+selection->GetLine()-1);
     list->Delete(selection->GetLine());
 
     configurationChanged=true;
