@@ -20,6 +20,8 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#include <Lum/Base/String.h>
+
 #include <Lum/Model/Action.h>
 #include <Lum/Model/Integer.h>
 #include <Lum/Model/Selection.h>
@@ -28,13 +30,49 @@
 
 #include <Lum/Dialog.h>
 
+#include "Configuration.h"
+
+typedef Lum::Model::StdRefTable<Tea,std::vector<Tea> > TeasModel;
+typedef Lum::Base::Reference<TeasModel>                TeasModelRef;
+
+class TeasDataProvider : public TeasModel::DataProvider
+{
+private:
+  std::wstring GetTimeString(size_t minutes, size_t seconds) const
+  {
+    std::wstring tmp;
+
+    tmp=Lum::Base::NumberToWString(minutes);
+    tmp.append(L":");
+    if (seconds<10) {
+      tmp.append(L"0");
+    }
+    tmp.append(Lum::Base::NumberToWString(seconds));
+
+    return tmp;
+  }
+
+public:
+  std::wstring GetString(const TeasModel::Iterator& iter, size_t column) const
+  {
+    switch (column) {
+    case 1:
+      return iter->name;
+    case 2:
+      return GetTimeString(iter->minutes,iter->seconds);
+    default:
+      assert(false);
+    }
+  }
+};
+
 class Selector : public Lum::Dialog
 {
 private:
   Lum::Model::StringRef              value;
   Lum::Model::IntRef                 minutes;
   Lum::Model::IntRef                 seconds;
-  Lum::Model::ListTableRef           list;
+  TeasModelRef                       list;
   Lum::Model::SingleLineSelectionRef selection;
 
   Lum::Model::ActionRef              addAction;
@@ -42,9 +80,6 @@ private:
   Lum::Model::ActionRef              removeAction;
   Lum::Model::ActionRef              okAction;
 
-private:
-  std::wstring GetTimeString(size_t minutes, size_t seconds) const;
-
 public:
   Selector(Lum::Model::Int* minutes, Lum::Model::Int *seconds);
 
