@@ -29,13 +29,11 @@ StopWatch::StopWatch()
    showInvert(false)
 {
   if (Lum::OS::display->GetType()==Lum::OS::Display::typeTextual) {
-    minFont=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                      Lum::OS::Display::fontScaleNormal);
+    minFont=Lum::OS::display->GetFont(Lum::OS::Display::fontScaleNormal);
     font=minFont;
     }
   else {
-    minFont=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeProportional,
-                                      500);
+    minFont=Lum::OS::display->GetFont(500);
     font=minFont;
   }
 
@@ -161,15 +159,9 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
   draw->PushFont(font,Lum::OS::Font::bold);
 
   if (alarm && showInvert) {
-    DrawBackground(x,y,w,h);
     draw->PushForeground(alarmColor);
   }
   else if (alarm) {
-    draw->PushClipBegin(x,y,w,h);
-    draw->SubClipRegion(this->x,this->y,this->width,this->height);
-    DrawBackground(x,y,w,h);
-    draw->PopClip();
-
     draw->PushForeground(alarmColor);
     draw->FillRectangle(this->x,this->y,this->width,this->height);
     draw->PopForeground();
@@ -177,7 +169,6 @@ void StopWatch::Draw(int x, int y, size_t w, size_t h)
     draw->PushForeground(Lum::OS::Display::textColor);
   }
   else {
-    DrawBackground(x,y,w,h);
     draw->PushForeground(Lum::OS::Display::textColor);
   }
 
